pub async fn parse_dbus_stats(
config: &Config,
connection: &Connection,
) -> Result<DBusStats, MonitordDbusStatsError>Expand description
Pull all units from dbus and count how system is setup and behaving
pub async fn parse_dbus_stats(
config: &Config,
connection: &Connection,
) -> Result<DBusStats, MonitordDbusStatsError>Pull all units from dbus and count how system is setup and behaving